Index: src/x64/macro-assembler-x64.h |
diff --git a/src/x64/macro-assembler-x64.h b/src/x64/macro-assembler-x64.h |
index b7183ff35d591d40a6027a7f673d0e21408a10fd..a7fd91cdd2f23368f32e74931a12a2f44850dd1f 100644 |
--- a/src/x64/macro-assembler-x64.h |
+++ b/src/x64/macro-assembler-x64.h |
@@ -342,8 +342,8 @@ class MacroAssembler: public Assembler { |
// Leave the current exit frame. Expects/provides the return value in |
// register rax:rdx (untouched) and the pointer to the first |
- // argument in register rsi. |
- void LeaveExitFrame(bool save_doubles = false); |
+ // argument in register rsi (if pop_arguments == true). |
+ void LeaveExitFrame(bool save_doubles = false, bool pop_arguments = true); |
// Leave the current exit frame. Expects/provides the return value in |
// register rax (untouched). |